@@ -10,8 +10,7 @@ from fiftyone import ViewField as F
 from fiftyone.utils.labels import (segmentations_to_detections,
                                    segmentations_to_polylines)
 
-tmpl_info = """
-info = {
+tmpl_info = """info = {
     'dataset_name': '$dataset_name',
     'dataset_type': '$dataset_type',
     'version': '$version',
@@ -267,8 +266,8 @@ def export_dataset(export_dir, dataset, label_field=None, mask_label_field=None,
     splits = dataset.distinct("tags")
 
     if not splits:
-        splits = ["all"]
-        dataset.tag_samples("all")
+        splits = ["train"]
+        dataset.tag_samples("train")
 
     for split in splits:
         print(f"\n[{split}]\n")
