@@ -10,6 +10,7 @@ Commands:
     frames
     info
     resize
+    unwarp
 """
 
 
@@ -36,6 +37,9 @@ def main(args=None):
     elif command == "resize":
         from hello.video.resize import main as _main
         _main(args)
+    elif command == "unwarp":
+        from hello.video.unwarp import main as _main
+        _main(args)
     else:
         print(help_doc_str)
 
